@@ -41,7 +41,7 @@ HeckmanEM.envelope <- function(obj, envelope=0.95, ...)
 {
 
   if(!inherits(obj,"HeckmanEM")) stop("Only \"HeckmanEM\" objects accepted!")
-  if (obj$family != "Normal" && obj$family !="normal" && obj$family !="T" && obj$family !="t" ) stop("Family not recognized")
+  if (obj$family != "Normal" && obj$family !="normal" && obj$family !="T" && obj$family !="t"  && obj$family !="CN" && obj$family !="cn") stop("Family not recognized")
 
   y <- obj$y
   x <- obj$x
@@ -58,14 +58,19 @@ HeckmanEM.envelope <- function(obj, envelope=0.95, ...)
   #res <- resMT(y, x, w, cc, beta=beta, gama=gama, rho=rho, sigma=sigma, nu, family) #old martingale envelopes
   if(family=="Normal" || family=="normal")
   {
-#' @importFrom PerformanceAnalytics chart.QQPlot
+    #' @importFrom PerformanceAnalytics chart.QQPlot
     PerformanceAnalytics::chart.QQPlot(res$resmt,distribution='norm',envelope=envelope,main="SLn", ...)
   }
-  else
+  if(family=="T" || family=="t")
   {
+    #' @importFrom PerformanceAnalytics chart.QQPlot
     PerformanceAnalytics::chart.QQPlot(res$resmt,distribution='norm',envelope=envelope,main="SLt", ...)
   }
-
+  if(family=="CN" || family=="cn")
+  {
+    #' @importFrom PerformanceAnalytics chart.QQPlot
+    PerformanceAnalytics::chart.QQPlot(res$resmt,distribution='norm',envelope=envelope,main="SLcn", ...)
+  }
 }
 
 ##-------------------------------##
@@ -75,7 +80,7 @@ resMT <- function(y, x, w, cc, beta=beta, gama=gama, rho=rho, sigma=sigma, nu, f
 {
 
   if(family == "normal" || family == "Normal") type <- "Normal"
-  else type <- "T"
+
   n<-nrow(x)
   y<-matrix(y,n,1)
   p<-ncol(x)
@@ -119,20 +124,21 @@ resMT <- function(y, x, w, cc, beta=beta, gama=gama, rho=rho, sigma=sigma, nu, f
 resGCS <- function(y, x, w, cc, beta=beta, gama=gama, rho=rho, sigma=sigma, nu, family= "Normal")
 {
 
-if(family == "normal" || family == "Normal") type <- "Normal"
-else type <- "T"
+  if(family == "normal" || family == "Normal") type <- "Normal"
+  if(family == "T" || family == "t") type <- "T"
+  if(family == "cn" || family == "CN") type <- "CN"
 
-n<-nrow(x)
-y<-matrix(y,n,1)
-p<-ncol(x)
-q<-ncol(w)
+  n<-nrow(x)
+  y<-matrix(y,n,1)
+  p<-ncol(x)
+  q<-ncol(w)
 
-sigma2 <- sigma^2
-rhoa<- sigma*rho
+  sigma2 <- sigma^2
+  rhoa<- sigma*rho
 
   resm <- resmt <- c()
 
-   S <-E<-matrix(0,n,1)
+  S <-E<-matrix(0,n,1)
   if(type=="Normal")
   {
     mu1 <- x%*%beta #
@@ -141,12 +147,12 @@ rhoa<- sigma*rho
     sigma12.1<- 1-rho^2
     Sigma<-matrix(c(sigma^2,sigma*rho,sigma*rho,1),2,2)
 
- for(i in 1:n){
-#' @importFrom MomTrunc pmvESN
-	 aux<-MomTrunc::pmvESN(c(-Inf,0),c(y[i],Inf),c(mu1[i],mu2[i]),Sigma,c(0,0),0)*cc[i]+pnorm(y[i]-mu2[i])*(1-cc[i])
- 	 S[i] <- stats::qnorm(aux)
- 	 E[i]  <-  -log(1-aux)
-  }
+    for(i in 1:n){
+      #' @importFrom MomTrunc pmvESN
+      aux<-MomTrunc::pmvESN(c(-Inf,0),c(y[i],Inf),c(mu1[i],mu2[i]),Sigma,c(0,0),0)*cc[i]+pnorm(y[i]-mu2[i])*(1-cc[i])
+      S[i] <- stats::qnorm(aux)
+      E[i]  <-  -log(1-aux)
+    }
   }
   if(type=="T")
   {
@@ -156,18 +162,40 @@ rhoa<- sigma*rho
     sigma12.1<- 1-rho^2
     Sigma<-matrix(c(sigma^2,sigma*rho,sigma*rho,1),2,2)
 
-     for(i in 1:n){
-#' @importFrom MomTrunc pmvEST
-	  aux<-MomTrunc::pmvEST(c(-Inf,0),c(y[i],Inf),c(mu1[i],mu2[i]),Sigma,c(0,0),0,nu)*cc[i]+pt(y[i]-mu2[i],nu)*(1-cc[i])
-	  S[i] <- stats::qnorm(aux)
-	  E[i]  <-  -log(1-aux)
+    for(i in 1:n){
+      #' @importFrom MomTrunc pmvEST
+      aux<-MomTrunc::pmvEST(c(-Inf,0),c(y[i],Inf),c(mu1[i],mu2[i]),Sigma,c(0,0),0,nu)*cc[i]+pt(y[i]-mu2[i],nu)*(1-cc[i])
+      S[i] <- stats::qnorm(aux)
+      E[i]  <-  -log(1-aux)
+    }
   }
+
+  if(type=="CN"){
+
+    nu1<-nu[1]
+    nu2<-nu[2]
+    mu1       <- x%*%beta # - sqrt(2/pi)*Delta
+    mu2       <- w%*%gama
+    mu12.1    <- mu2 + rho/sigma*(y - mu1)
+    sigma12.1 <- 1 - rho^2
+    Sigma     <- matrix(c(sigma^2, sigma*rho, sigma*rho, 1), 2, 2)
+
+    for(i in 1:n){
+      #' @importFrom MomTrunc pmvEST
+      aux.1<- MomTrunc::pmvESN(c(-Inf, 0), c(y[i], Inf), c(mu1[i], mu2[i]), Sigma/nu2, c(0, 0), 0)
+      aux.2<- MomTrunc::pmvESN(c(-Inf, 0), c(y[i], Inf), c(mu1[i], mu2[i]), Sigma, c(0, 0), 0)
+      aux  <- (nu1*aux.1+(1-nu1)*aux.2)*cc[i] + (nu1* pnorm(y[i], mu2[i],sqrt(1/nu2))+(1-nu1)* pnorm(y[i] - mu2[i]))*(1 - cc[i])
+      S[i] <- stats::qnorm(aux)
+      E[i] <- -log(1 - aux)
+    }
   }
 
 
+
   resmt<-S
   resm <-E
 
   return(list(resm=resm , resmt=resmt))
 }
 
+
